@@ -1,22 +1,31 @@
+__author__ = "Andrea Biancini, Jonas Geduldig"
+__date__ = "January 3, 2014"
+__license__ = "MIT"
+
 import base64
-import constants
+from .constants import USER_AGENT
 import requests
 
 
 class BearerAuth(requests.auth.AuthBase):
-	"""Request bearer access token for oAuth2 authentication."""
+	"""Request bearer access token for oAuth2 authentication.
+		
+	:param token_url: Twitter oAuth2 token access URL
+	:param consumer_key: Twitter application consumer key
+	:param consumer_secret: Twitter application consumer secret
+	"""
 	
 	def __init__(self, token_url, consumer_key, consumer_secret):
 		self._token_url = token_url
 		self._consumer_key = consumer_key
 		self._consumer_secret = consumer_secret
-		self._bearer_token = self.GetAccessToken()
+		self._bearer_token = self._get_access_token()
 
-	def GetAccessToken(self):
+	def _get_access_token(self):
 		b64_bearer_token_creds = base64.b64encode(self._consumer_key + ':' + self._consumer_secret)
 		params = {'grant_type':'client_credentials'}
 		headers = {}
-		headers['User-Agent'] = constants.USER_AGENT
+		headers['User-Agent'] = USER_AGENT
 		headers['Authorization'] = 'Basic ' + b64_bearer_token_creds
 		headers['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8'
 		try:
@@ -32,4 +41,4 @@ class BearerAuth(requests.auth.AuthBase):
 			r.headers['Authorization'] = "Bearer %s" % self._bearer_token
 			return r
 		else:
-			raise Exception('Not enough keys passed to Bearer token manager.')
\ No newline at end of file
+			raise Exception('Not enough keys passed to Bearer token manager.')
